'''
log module tests
'''

from nose import tools as nt

from CFchecker import log
from CFchecker.errors import MessageLogOverflow

class MessageLog_test:
    def test_init(self):
        '''MessageLog: test init'''
        l = log.MessageLog()
        nt.assert_equal(l.log, [])
        nt.assert_equal(l.log_not_implemented, False)
        nt.assert_equal(l.max_entries, 500)
    def test_add_log_entry(self):
        '''MessageLog: add raw log entry'''
        l = log.MessageLog()
        l._add_log_entry('RAW', '0.0', 'this is a test')
        nt.assert_equal(l.log, [('RAW', '0.0', 'this is a test')])
    def test_error(self):
        '''MessageLog: add error entry'''
        l = log.MessageLog()
        l.error('0.0', 'this is a test')
        nt.assert_equal(l.log, [('ERROR', '0.0', 'this is a test')])
    def test_warning(self):
        '''MessageLog: add warning entry'''
        l = log.MessageLog()
        l.warning('0.0', 'this is a test')
        nt.assert_equal(l.log, [('WARNING', '0.0', 'this is a test')])
    def test_info(self):
        '''MessageLog: add info entry'''
        l = log.MessageLog()
        l.info('0.0', 'this is a test')
        nt.assert_equal(l.log, [('INFO', '0.0', 'this is a test')])
    def test_not_implremented_log(self):
        '''MessageLog: "not implemented" entry mode on'''
        l = log.MessageLog(log_not_implemented=True)
        l.not_implemented('0.0', 'this is a test')
        nt.assert_equal(l.log, [('NOT IMPLEMENTED', '0.0', 'this is a test')])
    def test_not_implremented_nolog(self):
        '''MessageLog: "not implemented" entry mode off'''
        l = log.MessageLog(log_not_implemented=False)
        l.not_implemented('0.0', 'this is a test')
        nt.assert_equal(l.log, [])
    def test_entry_limit(self):
        '''MessageLog: respects max. entry limit'''
        l = log.MessageLog(max_entries=3)
        l.info('0.0', '1')
        l.info('0.0', '2')
        nt.assert_raises(MessageLogOverflow, l.info, '0.0', '3')
    def test_has_errors_true(self):
        '''MessageLog: has_errors() reports errors present'''
        l = log.MessageLog()
        l.error('0.0', 'this is a test')
        # with only an error entry
        nt.assert_true(l.has_errors())
        l.info('0.1', 'another test')
        # with another non-error entry
        nt.assert_true(l.has_errors())
    def test_has_errors_false(self):
        '''MessageLog: has_errors() reports no errors present '''
        l = log.MessageLog()
        # with no log entry at all
        nt.assert_false(l.has_errors())
        l.info('0.0', 'this is a test')
        # with info entry
        nt.assert_false(l.has_errors())
        l.warning('0.1', 'another test')
        # with another warning entry
        nt.assert_false(l.has_errors())
    def test_has_warnings_true(self):
        '''MessageLog: has_warnings() reports warnings present'''
        l = log.MessageLog()
        l.warning('0.0', 'this is a test')
        # with only a warning entry
        nt.assert_true(l.has_warnings())
        l.info('0.1', 'another test')
        # with another non-warning entry
        nt.assert_true(l.has_warnings())
    def test_has_warnings_false(self):
        '''MessageLog: has_errors() reports no warnings present'''
        l = log.MessageLog()
        # with no log entry at all
        nt.assert_false(l.has_warnings())
        l.info('0.0', 'this is a test')
        # with info entry
        nt.assert_false(l.has_warnings())
        l.error('0.1', 'another test')
        # with another error entry
        nt.assert_false(l.has_warnings())
    def test_str_convert(self):
        '''MessageLog: string conversion of log entries'''
        l = log.MessageLog()
        # empty log
        nt.assert_equal(str(l), '')
        # one entry
        l.error('0.0', 'test-error')
        nt.assert_equal(str(l), 'ERROR: 0.0:\ttest-error')
        # another entry
        l.info('0.1', 'test-info')
        nt.assert_equal(str(l), 'ERROR: 0.0:\ttest-error\nINFO: 0.1:\ttest-info')
        # and another entry
        l.warning('0.2', 'test-warning')
        nt.assert_equal(str(l), 'ERROR: 0.0:\ttest-error\nINFO: 0.1:\ttest-info\nWARNING: 0.2:\ttest-warning')
    def test_get_raw_log(self):
        '''MessageLog: get_raw_log() returns log entries'''
        l = log.MessageLog()
        nt.assert_equal(l.get_raw_log(), [])
        l.error('0.0', 'test-error')
        nt.assert_equal(l.get_raw_log(), [('ERROR', '0.0', 'test-error')])
        l.info('0.1', 'test-info')
        nt.assert_equal(l.get_raw_log(), [('ERROR', '0.0', 'test-error'), ('INFO', '0.1', 'test-info')])
    def test_clear(self):
        '''MessageLog: clear()'''
        l = log.MessageLog()
        l.error('0.0', 'test-error')
        nt.assert_true(len(l.get_raw_log()) > 0)
        l.clear()
        nt.assert_true(l.get_raw_log() == [])
